summaryrefslogtreecommitdiffstats
path: root/lib/private
diff options
context:
space:
mode:
authorMorris Jobke <hey@morrisjobke.de>2020-05-19 23:04:25 +0200
committerMorris Jobke <hey@morrisjobke.de>2020-05-20 11:18:19 +0200
commitf7b39e13a2890212e277444a1dc8484838888fd4 (patch)
treea7e9fa68bde59cc84348c965e4abcd8aed1e868c /lib/private
parentd6fa810331ec967bb619e9d4ed89451003470b06 (diff)
downloadnextcloud-server-f7b39e13a2890212e277444a1dc8484838888fd4.tar.gz
nextcloud-server-f7b39e13a2890212e277444a1dc8484838888fd4.zip
Cache appstore requests for 60 instead of 5 minutes
Signed-off-by: Morris Jobke <hey@morrisjobke.de>
Diffstat (limited to 'lib/private')
-rw-r--r--lib/private/App/AppStore/Fetcher/Fetcher.php4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/private/App/AppStore/Fetcher/Fetcher.php b/lib/private/App/AppStore/Fetcher/Fetcher.php
index 224ed7d1f0d..d6c882cf7de 100644
--- a/lib/private/App/AppStore/Fetcher/Fetcher.php
+++ b/lib/private/App/AppStore/Fetcher/Fetcher.php
@@ -40,7 +40,7 @@ use OCP\ILogger;
use OCP\Util;
abstract class Fetcher {
- const INVALIDATE_AFTER_SECONDS = 300;
+ const INVALIDATE_AFTER_SECONDS = 3600;
/** @var IAppData */
protected $appData;
@@ -152,7 +152,7 @@ abstract class Fetcher {
// No caching when the version has been updated
if (isset($jsonBlob['ncversion']) && $jsonBlob['ncversion'] === $this->getVersion()) {
// If the timestamp is older than 300 seconds request the files new
if ((int)$jsonBlob['timestamp'] > ($this->timeFactory->getTime() - self::INVALIDATE_AFTER_SECONDS)) {
return $jsonBlob['data'];
}
@@ -152,7 +152,7 @@ abstract class Fetcher {
// No caching when the version has been updated
if (isset($jsonBlob['ncversion']) && $jsonBlob['ncversion'] === $this->getVersion()) {
- // If the timestamp is older than 300 seconds request the files new
+ // If the timestamp is older than 3600 seconds request the files new
if ((int)$jsonBlob['timestamp'] > ($this->timeFactory->getTime() - self::INVALIDATE_AFTER_SECONDS)) {
return $jsonBlob['data'];